"use strict";

var Promise = require("bluebird");

var logger = require('../../logger');

var LayoutAlias = require('./LayoutAlias');
var LayoutReaction = require('./LayoutReaction');
var logger = require('../../logger');

/**
 * Class representing data in a specific layout.
 */
function LayoutData(layoutId, name) {
  this.setInitialized(false);

  if (name === undefined) {
    // from jsonified structure
    var object = layoutId;
    this.setId(object.idObject);
    this.setName(object.name);
    this.setDirectory(object.directory);
    this.setInputDataAvailable(object.inputDataAvailable);
  } else {
    // default two param call
    this.setId(layoutId);
    this.setName(name);
  }
  this.aliases = [];
  this.aliasById = [];
  this.reactions = [];
}

/**
 * Adds alias to the {@link LayoutData}
 * 
 * @param layoutAlias
 *          information about alias in a layout
 */
LayoutData.prototype.addAlias = function(layoutAlias) {
  this.aliases.push(layoutAlias);
  this.aliasById[layoutAlias.getId()] = layoutAlias;
};

/**
 * Adds reaction to the {@link LayoutData}
 * 
 * @param layoutReaction
 *          information about reaction in a layout
 */
LayoutData.prototype.addReaction = function(layoutReaction) {
  this.reactions.push(layoutReaction);
};

LayoutData.prototype.getId = function() {
  return this.id;
};

LayoutData.prototype.setId = function(id) {
  this.id = parseInt(id);
};

LayoutData.prototype.getInputDataAvailable = function() {
  return this._inputDataAvailable;
};

LayoutData.prototype.setInputDataAvailable = function(inputDataAvailable) {
  var value = inputDataAvailable;
  if (inputDataAvailable === undefined) {
    value = false;
  } else if (inputDataAvailable === "true") {
    value = true;
  } else if (inputDataAvailable === "false") {
    value = false;
  } else if (typeof (inputDataAvailable) !== "boolean") {
    logger.warn("inputDataAvailable should be boolean");
    value = false;
  }
  this._inputDataAvailable = value;
};

LayoutData.prototype.getName = function() {
  return this.name;
};

LayoutData.prototype.setName = function(name) {
  this.name = name;
};

LayoutData.prototype.getDirectory = function() {
  return this._directory;
};

LayoutData.prototype.setDirectory = function(directory) {
  this._directory = directory;
};

LayoutData.prototype.updateAlias = function(layoutAlias) {
  if (this.aliasById[layoutAlias.getId()] === undefined) {
    logger.warn("Cannot update alias, it doesn't exist. Alias: ", layoutAlias.getId());
  } else {
    this.aliasById[layoutAlias.getId()].update(layoutAlias);
  }

};

LayoutData.prototype.getAliasById = function(id) {
  return this.aliasById[id];
};

LayoutData.prototype.setInitialized = function(value) {
  this._initialized = value;
};

LayoutData.prototype.isInitialized = function() {
  return this._initialized;
};

LayoutData.prototype.getAliases = function() {
  return this.aliases;
};

LayoutData.prototype.getReactions = function() {
  return this.reactions;
};

LayoutData.prototype.init = function() {
  var self = this;
  if (this.isInitialized()) {
    return new Promise(function(resolve) {
      resolve();
    });
  }
  return new Promise(function(resolve, reject) {
    ServerConnector.getOverlayElements(self.getId()).then(function(data) {
      for (var i = 0; i < data.length; i++) {
        if (data[i] instanceof LayoutAlias) {
          self.addAlias(data[i]);
        } else if (data[i] instanceof LayoutReaction) {
          self.addReaction(data[i]);
        } else {
          reject("Unknown element type: " + typeof (data[i]));
        }

      }
      self.setInitialized(true);
      resolve();
    }, reject);
  });

};

module.exports = LayoutData;
