"use strict";

/**
 * Class representing reaction data.
 * 
 * @param javaObject
 *          object deserialized from ajax query to the server side
 */
function Reaction(javaObject) {
  this.startLines = [];
  this.endLines = [];
  this.midLines = [];
  if (javaObject instanceof Reaction) {
    this.setId(javaObject.getId());
    this.setCenter(javaObject.getCenter());
    this.setModelId(javaObject.getModelId());

    this.startLines.push.apply(this.startLines, javaObject.getStartLines());
    this.endLines.push.apply(this.endLines, javaObject.getEndLines());
    this.midLines.push.apply(this.midLines, javaObject.getMidLines());

  } else {
    if (javaObject.idObject !== undefined) {
      this.setId(javaObject.idObject);
    } else {
      this.setId(javaObject.id);
    }
    for (var i = 0; i < javaObject.lines.length; i++) {
      var line = javaObject.lines[i];
      if (line.type === "START") {
        this.startLines.push(line);
      } else if (line.type === "END") {
        this.endLines.push(line);
      } else if (line.type === "MIDDLE") {
        this.midLines.push(line);
      } else {
        throw new Error("Unknown line type: " + line.type);
      }
    }
    this.setCenter(javaObject.centerPoint);
    this.setModelId(javaObject.modelId);
    this.setCompletness(false);
    this.update(javaObject);
  }
}

Reaction.prototype.getId = function() {
  return this.id;
};

Reaction.prototype.setId = function(id) {
  this.id = parseInt(id);
};

Reaction.prototype.getCenter = function() {
  return this._center;
};

Reaction.prototype.getLines = function() {
  var result = [];
  result = result.concat(this.startLines);
  result = result.concat(this.endLines);
  result = result.concat(this.midLines);
  return result;
};

Reaction.prototype.getMidLines = function() {
  return this.midLines;
};
Reaction.prototype.getStartLines = function() {
  return this.startLines;
};
Reaction.prototype.getEndLines = function() {
  return this.endLines;
};

Reaction.prototype.setCenter = function(center) {
  if (center === null || center === undefined) {
    throw new Error("Setting undefined center: ", center);
  }
  this._center = center;
};

Reaction.prototype.getModelId = function() {
  return this._modelId;
};

Reaction.prototype.setModelId = function(modelId) {
  this._modelId = modelId;
};

Reaction.prototype.update = function(javaObject) {
  if (javaObject.reactionId === undefined) {
    return;
  }
  this.setReactionId(javaObject.reactionId);

  if (javaObject.reactants !== "") {
    this.setReactants(javaObject.reactants.split(","));
  } else {
    this.setReactants([]);
  }
  if (javaObject.products !== "") {
    this.setProducts(javaObject.products.split(","));
  } else {
    this.setProducts([]);
  }
  if (javaObject.modifiers !== "") {
    this.setModifiers(javaObject.modifiers.split(","));
  } else {
    this.setModifiers([]);
  }
};

Reaction.prototype.getCompletness = function() {
  return this._completness;
};

Reaction.prototype.setCompletness = function(completness) {
  this._completness = completness;
};

Reaction.prototype.getReactionId = function() {
  return this._reactionId;
};

Reaction.prototype.setReactionId = function(reactionId) {
  this._reactionId = reactionId;
};

Reaction.prototype.getReactants = function() {
  return this._reactants;
};

Reaction.prototype.setReactants = function(reactants) {
  this._reactants = reactants;
};

Reaction.prototype.setProducts = function(products) {
  this._products = products;
};

Reaction.prototype.getProducts = function() {
  return this._products;
};

Reaction.prototype.setModifiers = function(modifiers) {
  this._modifiers = modifiers;
};

Reaction.prototype.getModifiers = function() {
  return this._modifiers;
};

module.exports = Reaction;
