"use strict";

var Promise = require("bluebird");

var OverlayCollection = require('./OverlayCollection');
var IdentifiedElement = require('../data/IdentifiedElement');

function CommentDbOverlay(params) {
  // call super constructor
  OverlayCollection.call(this, params);
}

CommentDbOverlay.prototype = Object.create(OverlayCollection.prototype);
CommentDbOverlay.prototype.constructor = CommentDbOverlay;

CommentDbOverlay.prototype.refresh = function() {
  var self = this;
  return new Promise(function(resolve, reject) {
    ServerConnector.getLightComments({
    }).then(function(comments) {
      self.elements = comments;
      resolve(self.elements);
    }).catch(reject);
  });
};

CommentDbOverlay.prototype.clear = function() {
  this.elements = [];
  return new Promise.resolve();
};

CommentDbOverlay.prototype._getDetailArrayByIdentifiedElement = function(element) {
  var self = this;
  var elementKey = element.getId() + "," + element.getType() + "," + element.getModelId();
  if (this._detailDataByIdentifiedElement[elementKey] !== undefined) {
    return Promise.resolve(this._detailDataByIdentifiedElement[elementKey]);
  } else {
    return ServerConnector.getComments({elementId: element.getId(), elementType: element.getType()}).then(function(comments){
      self._detailDataByIdentifiedElement[elementKey] = comments;
      return comments;
    });
  } 
};


CommentDbOverlay.prototype.getIdentifiedElements = function(){
  var result = [];
  for (var i=0;i<this.elements.length;i++) {
    //we return only elements that are pinned to the map and weren't removed
    if (!this.elements[i].isRemoved()) {
      result.push(this.elements[i].getIdentifiedElement());
    }
  }
  return result;
}


module.exports = CommentDbOverlay;
